//
//  SITLocationError.h
//  SitumSDK
//
//  Created by A Barros on 27/2/17.
//  Copyright © 2017 Situm. All rights reserved.
//

#ifndef SITLocationError_h
#define SITLocationError_h

/**
 Domain error
 */
extern NSString *const kSITLocationErrorDomain;


/**
 Type of error the location manager can return.

 - kSITLocationErrorNetwork: there was a network error.
 - kSITLocationErrorUnauthorized: you have not permissions access the information because you are not allowed to see it.
 - kSITLocationErrorBadRequest: there is a problem with parameters.
 - kSITLocationErrorPermissionDenied: you have no permissions to use the location of the user.
 - kSITLocationErrorAlreadyStarted: you can only start the system once.
 - kSITLocationErrorSystemStopped: you can only stop the system when is previosly started.
 - kSITLocationErrorBluetoothIsOff: bluetooth is turned off
 - kSITLocationErrorBluetoothUnauthorized: bluetooth permission is not granted
 - kSITLocationErrorLocationDisabled: location services are disabled
 - kSITLocationErrorLocationRestricted: location permission is not granted
 - kSITLocationErrorLocationAuthStatusNotDetermined: permission to use location services has not been granted or rejected yet
 - kSITLocationErrorBuildingModelNotAvaliable: model couldn't be processed (error in download, unzip or file moves)
 - kSITLocationErrorBuildingNotCalibrated: building has no model, it needs to be calibrated first
 */
typedef NS_ENUM(NSInteger, SITLocationError) {
    kSITLocationErrorNetwork = 0,
    kSITLocationErrorUnauthorized,
    kSITLocationErrorBadRequest,
    kSITLocationErrorPermissionDenied,
    kSITLocationErrorAlreadyStarted,
    kSITLocationErrorSystemStopped,
    kSITLocationErrorBluetoothIsOff,
    kSITLocationErrorBluetoothUnauthorized,
    kSITLocationErrorLocationDisabled,
    kSITLocationErrorLocationRestricted,
    kSITLocationErrorLocationAuthStatusNotDetermined,
    kSITLocationErrorBuildingModelNotAvaliable,
    kSITLocationErrorBuildingNotCalibrated
};


#endif /* SITLocationError_h */
